<?php

class PrestamoSystemClass {

  private $o_ParamBean;
  
  public function __construct($o_ParamBean){
    $this->o_ParamBean = $o_ParamBean;
  }
  
  private function getObjParamBean(){
    return $this->o_ParamBean;
  }
  
  public function insertPrestamo(){
    
    $o_PrestamoBL = new PrestamoBL();
    return $o_PrestamoBL->insertarPrestamo($this->getObjParamBean());
    
  }
  
  public function insertUsuario($o_UsuarioBean){
    $o_UsuarioBL = new UsuarioBL();
    $o_UsuarioBL->insertarUsuario($o_UsuarioBean);
  }
  

   
  public function eliminarPrestamo(){
    
    $o_PrestamoBL = new PrestamoBL();
    return $o_PrestamoBL->eliminarPrestamo($this->getObjParamBean());
    
  }
  
  public function actualizarPrestamo(){
    
    $o_PrestamoBL = new PrestamoBL();
    return $o_PrestamoBL->modificarPrestamo($this->getObjParamBean());
    
  }
  
  public function getPrestamo(){
  
    $o_PrestamoBL = new PrestamoBL();
    return $o_PrestamoBL->busquedaPrestamo($this->getObjParamBean());
  
  }
  
//  public function getprestamo(){
//  
//    $o_prestamobl = new prestamobl();
//    return $o_prestamobl->getprestamo($this->getobjparambean());
//  
//  }
  
  
   public function getMercado(){
    $o_MercadoBL = new MercadoBL();
    return $o_MercadoBL->busquedaMercado(new MercadoBean());
    
  }
   public function getTipoNegocio(){
    $o_TipoNegocioBL = new TipoNegocioBL();
    return $o_TipoNegocioBL->busquedaTipoNegocio(new TipoNegocioBean());
    
  }
  
  public function getEspecialidad(){
    
    $o_EspecialidadBL = new EspecialidadBL();
    return $o_EspecialidadBL->getEspecialidad($this->getObjParamBean());
  }
  

}